==> gs2-java-sdk-3.1.8-sources.jar: io/gs2/showcase/model/SalesItemGroupMaster.java <==
/*
 * Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package io.gs2.showcase.model;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.StreamSupport;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.JsonNode;
import io.gs2.core.model.IModel;


@SuppressWarnings("serial")
@JsonIgnoreProperties(ignoreUnknown=true)
public class SalesItemGroupMaster implements IModel, Serializable, Comparable<SalesItemGroupMaster> {
	private String salesItemGroupId;
	private String name;
	private String description;
	private String metadata;
	private List<String> salesItemNames;
	private Long createdAt;
	private Long updatedAt;

	public String getSalesItemGroupId() {
		return salesItemGroupId;
	}

	public void setSalesItemGroupId(String salesItemGroupId) {
		this.salesItemGroupId = salesItemGroupId;
	}

	public SalesItemGroupMaster withSalesItemGroupId(String salesItemGroupId) {
		this.salesItemGroupId = salesItemGroupId;
		return this;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public SalesItemGroupMaster withName(String name) {
		this.name = name;
		return this;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public SalesItemGroupMaster withDescription(String description) {
		this.description = description;
		return this;
	}

	public String getMetadata() {
		return metadata;
	}

	public void setMetadata(String metadata) {
		this.metadata = metadata;
	}

	public SalesItemGroupMaster withMetadata(String metadata) {
		this.metadata = metadata;
		return this;
	}

	public List<String> getSalesItemNames() {
		return salesItemNames;
	}

	public void setSalesItemNames(List<String> salesItemNames) {
		this.salesItemNames = salesItemNames;
	}

	public SalesItemGroupMaster withSalesItemNames(List<String> salesItemNames) {
		this.salesItemNames = salesItemNames;
		return this;
	}

	public Long getCreatedAt() {
		return createdAt;
	}

	public void setCreatedAt(Long createdAt) {
		this.createdAt = createdAt;
	}

	public SalesItemGroupMaster withCreatedAt(Long createdAt) {
		this.createdAt = createdAt;
		return this;
	}

	public Long getUpdatedAt() {
		return updatedAt;
	}

	public void setUpdatedAt(Long updatedAt) {
		this.updatedAt = updatedAt;
	}

	public SalesItemGroupMaster withUpdatedAt(Long updatedAt) {
		this.updatedAt = updatedAt;
		return this;
	}

    public static SalesItemGroupMaster fromJson(JsonNode data) {
        if (data == null) {
            return null;
        }
        return new SalesItemGroupMaster()
            .withSalesItemGroupId(data.get("salesItemGroupId") == null || data.get("salesItemGroupId").isNull() ? null : data.get("salesItemGroupId").asText())
            .withName(data.get("name") == null || data.get("name").isNull() ? null : data.get("name").asText())
            .withDescription(data.get("description") == null || data.get("description").isNull() ? null : data.get("description").asText())
            .withMetadata(data.get("metadata") == null || data.get("metadata").isNull() ? null : data.get("metadata").asText())
            .withSalesItemNames(data.get("salesItemNames") == null || data.get("salesItemNames").isNull() ? new ArrayList<String>() :
                StreamSupport.stream(Spliterators.spliteratorUnknownSize(data.get("salesItemNames").elements(), Spliterator.NONNULL), false).map(item -> {
                    return item.asText();
                }
            ).collect(Collectors.toList()))
            .withCreatedAt(data.get("createdAt") == null || data.get("createdAt").isNull() ? null : data.get("createdAt").longValue())
            .withUpdatedAt(data.get("updatedAt") == null || data.get("updatedAt").isNull() ? null : data.get("updatedAt").longValue());
    }

    public JsonNode toJson() {
        return new ObjectMapper().valueToTree(
            new HashMap<String, Object>() {{
                put("salesItemGroupId", getSalesItemGroupId());
                put("name", getName());
                put("description", getDescription());
                put("metadata", getMetadata());
                put("salesItemNames", getSalesItemNames() == null ? new ArrayList<String>() :
                    getSalesItemNames().stream().map(item -> {
                        return item;
                    }
                ).collect(Collectors.toList()));
                put("createdAt", getCreatedAt());
                put("updatedAt", getUpdatedAt());
            }}
        );
    }

	@Override
	public int compareTo(SalesItemGroupMaster o) {
		return salesItemGroupId.compareTo(o.salesItemGroupId);
	}

	@Override
	public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((this.salesItemGroupId == null) ? 0 : this.salesItemGroupId.hashCode());
        result = prime * result + ((this.name == null) ? 0 : this.name.hashCode());
        result = prime * result + ((this.description == null) ? 0 : this.description.hashCode());
        result = prime * result + ((this.metadata == null) ? 0 : this.metadata.hashCode());
        result = prime * result + ((this.salesItemNames == null) ? 0 : this.salesItemNames.hashCode());
        result = prime * result + ((this.createdAt == null) ? 0 : this.createdAt.hashCode());
        result = prime * result + ((this.updatedAt == null) ? 0 : this.updatedAt.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object o) {
		if (this == o)
			return true;
		if (o == null)
			return false;
		if (getClass() != o.getClass())
			return false;
		SalesItemGroupMaster other = (SalesItemGroupMaster) o;
		if (salesItemGroupId == null) {
			return other.salesItemGroupId == null;
		} else if (!salesItemGroupId.equals(other.salesItemGroupId)) {
			return false;
		}
		if (name == null) {
			return other.name == null;
		} else if (!name.equals(other.name)) {
			return false;
		}
		if (description == null) {
			return other.description == null;
		} else if (!description.equals(other.description)) {
			return false;
		}
		if (metadata == null) {
			return other.metadata == null;
		} else if (!metadata.equals(other.metadata)) {
			return false;
		}
		if (salesItemNames == null) {
			return other.salesItemNames == null;
		} else if (!salesItemNames.equals(other.salesItemNames)) {
			return false;
		}
		if (createdAt == null) {
			return other.createdAt == null;
		} else if (!createdAt.equals(other.createdAt)) {
			return false;
		}
		if (updatedAt == null) {
			return other.updatedAt == null;
		} else if (!updatedAt.equals(other.updatedAt)) {
			return false;
		}
		return true;
	}
}

==> gs2-java-sdk-3.1.154-sources.jar: io/gs2/showcase/model/SalesItemGroupMaster.java <==
/*
 * Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package io.gs2.showcase.model;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.StreamSupport;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.JsonNode;
import io.gs2.core.model.IModel;


@SuppressWarnings("serial")
@JsonIgnoreProperties(ignoreUnknown=true)
public class SalesItemGroupMaster implements IModel, Serializable, Comparable<SalesItemGroupMaster> {
	private String salesItemGroupId;
	private String name;
	private String description;
	private String metadata;
	private List<String> salesItemNames;
	private Long createdAt;
	private Long updatedAt;
	private Long revision;
	public String getSalesItemGroupId() {
		return salesItemGroupId;
	}
	public void setSalesItemGroupId(String salesItemGroupId) {
		this.salesItemGroupId = salesItemGroupId;
	}
	public SalesItemGroupMaster withSalesItemGroupId(String salesItemGroupId) {
		this.salesItemGroupId = salesItemGroupId;
		return this;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public SalesItemGroupMaster withName(String name) {
		this.name = name;
		return this;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public SalesItemGroupMaster withDescription(String description) {
		this.description = description;
		return this;
	}
	public String getMetadata() {
		return metadata;
	}
	public void setMetadata(String metadata) {
		this.metadata = metadata;
	}
	public SalesItemGroupMaster withMetadata(String metadata) {
		this.metadata = metadata;
		return this;
	}
	public List<String> getSalesItemNames() {
		return salesItemNames;
	}
	public void setSalesItemNames(List<String> salesItemNames) {
		this.salesItemNames = salesItemNames;
	}
	public SalesItemGroupMaster withSalesItemNames(List<String> salesItemNames) {
		this.salesItemNames = salesItemNames;
		return this;
	}
	public Long getCreatedAt() {
		return createdAt;
	}
	public void setCreatedAt(Long createdAt) {
		this.createdAt = createdAt;
	}
	public SalesItemGroupMaster withCreatedAt(Long createdAt) {
		this.createdAt = createdAt;
		return this;
	}
	public Long getUpdatedAt() {
		return updatedAt;
	}
	public void setUpdatedAt(Long updatedAt) {
		this.updatedAt = updatedAt;
	}
	public SalesItemGroupMaster withUpdatedAt(Long updatedAt) {
		this.updatedAt = updatedAt;
		return this;
	}
	public Long getRevision() {
		return revision;
	}
	public void setRevision(Long revision) {
		this.revision = revision;
	}
	public SalesItemGroupMaster withRevision(Long revision) {
		this.revision = revision;
		return this;
	}

    public static SalesItemGroupMaster fromJson(JsonNode data) {
        if (data == null) {
            return null;
        }
        return new SalesItemGroupMaster()
            .withSalesItemGroupId(data.get("salesItemGroupId") == null || data.get("salesItemGroupId").isNull() ? null : data.get("salesItemGroupId").asText())
            .withName(data.get("name") == null || data.get("name").isNull() ? null : data.get("name").asText())
            .withDescription(data.get("description") == null || data.get("description").isNull() ? null : data.get("description").asText())
            .withMetadata(data.get("metadata") == null || data.get("metadata").isNull() ? null : data.get("metadata").asText())
            .withSalesItemNames(data.get("salesItemNames") == null || data.get("salesItemNames").isNull() ? new ArrayList<String>() :
                StreamSupport.stream(Spliterators.spliteratorUnknownSize(data.get("salesItemNames").elements(), Spliterator.NONNULL), false).map(item -> {
                    return item.asText();
                }
            ).collect(Collectors.toList()))
            .withCreatedAt(data.get("createdAt") == null || data.get("createdAt").isNull() ? null : data.get("createdAt").longValue())
            .withUpdatedAt(data.get("updatedAt") == null || data.get("updatedAt").isNull() ? null : data.get("updatedAt").longValue())
            .withRevision(data.get("revision") == null || data.get("revision").isNull() ? null : data.get("revision").longValue());
    }

    public JsonNode toJson() {
        return new ObjectMapper().valueToTree(
            new HashMap<String, Object>() {{
                put("salesItemGroupId", getSalesItemGroupId());
                put("name", getName());
                put("description", getDescription());
                put("metadata", getMetadata());
                put("salesItemNames", getSalesItemNames() == null ? new ArrayList<String>() :
                    getSalesItemNames().stream().map(item -> {
                        return item;
                    }
                ).collect(Collectors.toList()));
                put("createdAt", getCreatedAt());
                put("updatedAt", getUpdatedAt());
                put("revision", getRevision());
            }}
        );
    }

	@Override
	public int compareTo(SalesItemGroupMaster o) {
		return salesItemGroupId.compareTo(o.salesItemGroupId);
	}

	@Override
	public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((this.salesItemGroupId == null) ? 0 : this.salesItemGroupId.hashCode());
        result = prime * result + ((this.name == null) ? 0 : this.name.hashCode());
        result = prime * result + ((this.description == null) ? 0 : this.description.hashCode());
        result = prime * result + ((this.metadata == null) ? 0 : this.metadata.hashCode());
        result = prime * result + ((this.salesItemNames == null) ? 0 : this.salesItemNames.hashCode());
        result = prime * result + ((this.createdAt == null) ? 0 : this.createdAt.hashCode());
        result = prime * result + ((this.updatedAt == null) ? 0 : this.updatedAt.hashCode());
        result = prime * result + ((this.revision == null) ? 0 : this.revision.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object o) {
		if (this == o)
			return true;
		if (o == null)
			return false;
		if (getClass() != o.getClass())
			return false;
		SalesItemGroupMaster other = (SalesItemGroupMaster) o;
		if (salesItemGroupId == null) {
			return other.salesItemGroupId == null;
		} else if (!salesItemGroupId.equals(other.salesItemGroupId)) {
			return false;
		}
		if (name == null) {
			return other.name == null;
		} else if (!name.equals(other.name)) {
			return false;
		}
		if (description == null) {
			return other.description == null;
		} else if (!description.equals(other.description)) {
			return false;
		}
		if (metadata == null) {
			return other.metadata == null;
		} else if (!metadata.equals(other.metadata)) {
			return false;
		}
		if (salesItemNames == null) {
			return other.salesItemNames == null;
		} else if (!salesItemNames.equals(other.salesItemNames)) {
			return false;
		}
		if (createdAt == null) {
			return other.createdAt == null;
		} else if (!createdAt.equals(other.createdAt)) {
			return false;
		}
		if (updatedAt == null) {
			return other.updatedAt == null;
		} else if (!updatedAt.equals(other.updatedAt)) {
			return false;
		}
		if (revision == null) {
			return other.revision == null;
		} else if (!revision.equals(other.revision)) {
			return false;
		}
		return true;
	}
}
